==> boinc_6.13.1+dfsg.orig.tar.gz: boinc-6.13.1+dfsg/clientgui/sg_ProjectWebSitesPopup.h <==
// This file is part of BOINC.
// http://boinc.berkeley.edu
// Copyright (C) 2008 University of California
//
// BOINC is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// BOINC is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.

#ifndef __sg_ProjectWebsitesPopup__
#define __sg_ProjectWebsitesPopup__


class CSimpleProjectWebSitesPopupButton : public wxButton 
{
    DECLARE_DYNAMIC_CLASS( CSimpleProjectWebSitesPopupButton )
    DECLARE_EVENT_TABLE()

    public:
        CSimpleProjectWebSitesPopupButton();
        
		CSimpleProjectWebSitesPopupButton(wxWindow* parent, wxWindowID id, 
        const wxString& label = wxEmptyString, 
        const wxPoint& pos = wxDefaultPosition, 
        const wxSize& size = wxDefaultSize, 
        long style = 0, 
        const wxValidator& validator = wxDefaultValidator, 
        const wxString& name = wxT("ProjectWebsitesPopupMenu"));
        
		~CSimpleProjectWebSitesPopupButton();
        
        void RebuildMenu();

	private:
        void AddMenuItems();
        void OnProjectWebSiteButton(wxMouseEvent& event);
        void OnMenuLinkClicked(wxCommandEvent& event);

	protected:
        wxMenu*                     m_ProjectWebSitesPopUpMenu;
};

#endif // __sg_ProjectWebsitesPopup__

==> boinc_7.2.47+dfsg.orig.tar.gz: boinc-7.2.47+dfsg/clientgui/sg_ProjectWebSitesPopup.h <==
// This file is part of BOINC.
// http://boinc.berkeley.edu
// Copyright (C) 2008 University of California
//
// BOINC is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// BOINC is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.

#ifndef __sg_ProjectWebsitesPopup__
#define __sg_ProjectWebsitesPopup__

#include "sg_CustomControls.h"

class CSimpleProjectWebSitesPopupButton : public CTransparentButton 
{
    DECLARE_DYNAMIC_CLASS( CSimpleProjectWebSitesPopupButton )
    DECLARE_EVENT_TABLE()

    public:
        CSimpleProjectWebSitesPopupButton();
        
		CSimpleProjectWebSitesPopupButton(wxWindow* parent, wxWindowID id, 
        const wxString& label = wxEmptyString, 
        const wxPoint& pos = wxDefaultPosition, 
        const wxSize& size = wxDefaultSize, 
        long style = 0, 
        const wxValidator& validator = wxDefaultValidator, 
        const wxString& name = wxT("ProjectWebsitesPopupMenu"));
        
		~CSimpleProjectWebSitesPopupButton();
        
        void RebuildMenu();

	private:
        void AddMenuItems();
        void OnProjectWebSiteButton(wxMouseEvent& event);
        void OnMenuLinkClicked(wxCommandEvent& event);

	protected:
        wxMenu*                     m_ProjectWebSitesPopUpMenu;
};

#endif // __sg_ProjectWebsitesPopup__
